@@ -1,4 +1,4 @@
-pub use c3p0 as c3p0;
+pub use c3p0;
 
 #[cfg(feature = "auth")]
 pub use lightspeed_auth as auth;
